==> worlds_trackmania-1.3.1.tar.gz: worlds_trackmania-1.3.1/src/worlds/trackmania/docs/setup_en.md <==
# Trackmania Archipelago Setup Guide!

## Required Software

- Trackmania (2020) Club Access OR any Trackmania 2 game (Canyon, Stadium, Valley, or Lagoon)
- [Openplanet](https://openplanet.dev/)
- [MultiworldGG Launcher](https://multiworld.gg/tutorial/Archipelago/setup/en)

## Instructions

1. Make sure you have Openplanet installed for your Trackmania game. The Openplanet installer will walk you through all the required steps.

2. Open the Openplanet overlay in-game with the 'F3' key, click Plugin Manager, search for the plugin called 'Archipelago', and click install

3. You should be good to go!

## Connecting to an Archipelago Server

To connect to a server, simply run the **MultiworldGG Trackmania Client** from the **MultiworldGG Launcher**, and use the 
/connect command or the header bar to connect to the server. Once the client is connected to the server, you must connect the Trackmania Plugin to the client. In the Openplanet overlay, click Scripts -> Archipelago to open the Archipelago Plugin window, and click Connect.

## Client Console Commands

`/trackmania` - Reports if the client is connected to the Trackmania plugin

`/reroll` - Replaces the currently loaded map with a new one from Trackmania Exchange. This is intended to be used only if a map is broken, impossible, or you become soft-locked.

`/reroll <series_number> <map_number>` - Replaces the specified map with a new one from Trackmania Exchange. 
This is intended to be used from the main menu only if a map is impossible to load.

==> worlds_trackmania-1.3.2.tar.gz: worlds_trackmania-1.3.2/src/worlds/trackmania/docs/setup_en.md <==
# Trackmania MultiworldGG Setup Guide!

## Required Software

- Trackmania (2020) Club Access OR any Trackmania 2 game (Canyon, Stadium, Valley, or Lagoon)
- [Openplanet](https://openplanet.dev/)
- [MultiworldGG Launcher](https://multiworld.gg/tutorial/Archipelago/setup/en)

## Instructions

1. Make sure you have Openplanet installed for your Trackmania game. The Openplanet installer will walk you through all the required steps.

2. Open the Openplanet overlay in-game with the 'F3' key, click Plugin Manager, search for the plugin called 'Archipelago', and click install

3. You should be good to go!

## Connecting to a MultiworldGG Server

To connect to a server, simply run the **MultiworldGG Trackmania Client** from the **MultiworldGG Launcher**, and use the 
/connect command or the header bar to connect to the server. Once the client is connected to the server, you must connect the Trackmania Plugin to the client. In the Openplanet overlay, click Scripts -> Archipelago to open the Archipelago Plugin window, and click Connect.

## Client Console Commands

`/trackmania` - Reports if the client is connected to the Trackmania plugin

`/reroll` - Replaces the currently loaded map with a new one from Trackmania Exchange. This is intended to be used only if a map is broken, impossible, or you become soft-locked.

`/reroll <series_number> <map_number>` - Replaces the specified map with a new one from Trackmania Exchange. 
This is intended to be used from the main menu only if a map is impossible to load.
